@@ -26,18 +26,18 @@
 #include <QScrollArea>
 #include <QStatusBar>
 
-#include <kparts/guiactivateevent.h>
-#include <kmessagebox.h>
-#include <kshortcutsdialog.h>
-#include <kedittoolbar.h>
 #include "kimagemapeditor_debug.h"
-#include <kxmlguifactory.h>
-#include <kstandardaction.h>
-#include <ktoolbar.h>
-#include <kactioncollection.h>
-#include <KSharedConfig>
+#include <KActionCollection>
 #include <KConfigGroup>
+#include <KEditToolBar>
+#include <KMessageBox>
+#include <KParts/GUIActivateEvent>
+#include <KSharedConfig>
+#include <KShortcutsDialog>
+#include <KStandardAction>
+#include <KToolBar>
 #include <KWindowConfig>
+#include <KXMLGUIFactory>
 
 #include "drawzone.h"
 #include "kimagemapeditor.h"	// the KPart
@@ -57,7 +57,7 @@ KimeShell::KimeShell(const char * )
 //  mainDock->setWidget( w );
   // allow others to dock to the 4 sides
   //  mainDock->setDockSite(K3DockWidget::DockCorner);
-  // forbit docking abilities of mainDock itself
+  // forbid docking abilities of mainDock itself
   //  mainDock->setEnableDocking(K3DockWidget::DockNone);
   //  setView( mainDock); // central widget in a KDE mainwindow
   //  setMainDockWidget( mainDock); // master dockwidget
